@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::C;
-$Time::C::VERSION = '0.014';
+$Time::C::VERSION = '0.015';
 # ABSTRACT: Convenient time manipulation.
 
 use overload (
@@ -347,7 +347,7 @@ method string ($t: $new_str = undef, :$format = undef, :$locale = 'C', :$strict
 }
 
 
-method strftime ($t: $format = undef, $new_str = undef) :lvalue { $t->string(@_); }
+method strftime ($t: $new_str = undef, :$format = undef, :$locale = 'C', :$strict = 1) :lvalue { $t->string(@_); }
 
 
 method year ($t: $new_year = undef) :lvalue {
@@ -577,7 +577,7 @@ Time::C - Convenient time manipulation.
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -689,7 +689,7 @@ C<$minute> sets the minute of the day/hour, depending on what other options were
 
 =item C<< hour => $hour >>
 
-C<$hout> sets the hour of the day.
+C<$hour> sets the hour of the day.
 
 =item C<< mday => $mday >>
 
